.. _tutorial:

Flotilla tutorial
=================

Installation
------------

.. toctree::
    :maxdepth: 2

    installation

Beginning examples
------------------

.. toctree::
    :maxdepth: 1

    tutorial/barebones_study_making

Advanced examples
-----------------

.. toctree::
    :maxdepth: 1

    tutorial/modalities

Day to day helpful tips
-----------------------

.. toctree::
    :maxdepth: 2

    tutorial/supplementaldata


.. Plotting functions
   ------------------
   .. toctree::
       :maxdepth: 1
        tutorial/pca
        tutorial/classification
        tutorial/network
        tutorial/expression_specific
        tutorial/splicing_specific

Recreated papers
----------------

.. toctree::
    :maxdepth: 1

    tutorial/shalek2013
